@@ -132,7 +132,13 @@ modelLookup <- function(model = NULL)
                            "pda",
                            "pda2",
                            "qda",
-                           "glmnet", "glmnet"
+                           "glmnet", "glmnet",
+                           "relaxo", "relaxo",
+                           "lars",
+                           "lars2",
+                           "OneR",
+                           "PART",
+                           "PART"
                            ),
                          parameter = c(
                            "parameter",      
@@ -199,7 +205,13 @@ modelLookup <- function(model = NULL)
                            "lambda",
                            "df",
                            "parameter",
-                           "lambda", "alpha"
+                           "lambda", "alpha",
+                           "lambda", "phi",
+                           "fraction",
+                           "step",
+                           "parameter",
+                           "threshold",
+                           "pruned"
                            ),
                          label = I(c(
                            "none",      
@@ -267,7 +279,14 @@ modelLookup <- function(model = NULL)
                            "Degrees of Freedom",
                            "none",
                            "Regularization Parameter",
-                           "Mixing Percentage"
+                           "Mixing Percentage",
+                           "Penalty Parameter",
+                           "Relaxation Parameter",
+                           "Fraction",
+                           "#Steps",
+                           "none",
+                           "Confidence Threshold",
+                           "Pruning"
                            )),
                          seq = c(
                            FALSE,
@@ -334,7 +353,12 @@ modelLookup <- function(model = NULL)
                            FALSE,
                            FALSE,
                            FALSE,
-                           TRUE,  FALSE
+                           TRUE,  FALSE,
+                           TRUE,  FALSE,
+                           TRUE,
+                           TRUE,
+                           FALSE,
+                           FALSE, FALSE
                            ),
                          forReg = c(
                            TRUE,
@@ -401,7 +425,12 @@ modelLookup <- function(model = NULL)
                            FALSE,
                            FALSE,
                            FALSE,
-                           TRUE,  TRUE
+                           TRUE,  TRUE,
+                           TRUE, TRUE,
+                           TRUE,
+                           TRUE,
+                           FALSE,
+                           FALSE,  FALSE
                            ),               
                          forClass =          
                          c(
@@ -469,6 +498,11 @@ modelLookup <- function(model = NULL)
                            TRUE,
                            TRUE,
                            TRUE,
+                           TRUE,  TRUE,
+                           FALSE, FALSE,
+                           FALSE,
+                           FALSE,
+                           TRUE,
                            TRUE,  TRUE
                            ),
                          probModel = c(
@@ -536,7 +570,12 @@ modelLookup <- function(model = NULL)
                            TRUE,
                            TRUE,
                            TRUE,
-                           TRUE, TRUE        # glmnet
+                           TRUE,  TRUE,       # glmnet
+                           FALSE, FALSE,      # relaxo,
+                           FALSE,             # lars
+                           FALSE,             # lars2
+                           TRUE,              # OneR
+                           TRUE, TRUE         # PART
                             ),
                          stringsAsFactors  = FALSE               
                          )         
@@ -770,7 +809,36 @@ tuneScheme <- function(model, grid, useOOB = FALSE)
                  {
                    seqParam[[i]] <- data.frame(.lambda = subset(grid, subset = .alpha == uniqueAlpha[i])$.lambda)
                  } 
-             }
+             },
+             relaxo =
+             {
+
+               loop <- aggregate(
+                                 grid$.lambda, 
+                                 list(.phi = grid$.phi),
+                                 max)
+               names(loop) <- c(".phi", ".lambda")
+               
+               seqParam <- vector(mode = "list", length = nrow(loop))
+               
+               for(i in seq(along = seqParam))
+                 {
+                   seqParam[[i]] <- data.frame(.lambda = subset(grid,
+                                                 subset = .phi == loop$.phi[i] & .lambda < loop$.lambda[i])$.lambda)
+                 } 
+             },
+             lars = 
+             {
+               grid <- grid[order(grid$.fraction, decreasing = TRUE),, drop = FALSE]
+               loop <- grid[1,,drop = FALSE]
+               seqParam <- list(grid[-1,,drop = FALSE])
+             },
+             lars2 = 
+             {
+               grid <- grid[order(grid$.step, decreasing = TRUE),, drop = FALSE]
+               loop <- grid[1,,drop = FALSE]
+               seqParam <- list(grid[-1,,drop = FALSE])
+             }             
              )
       out <- list(scheme = "seq", loop = loop, seqParam = seqParam, model = modelInfo, constant = constant, vary = vary)
     } else out <- list(scheme = "basic", loop = grid, seqParam = NULL, model = modelInfo, constant = names(grid), vary = NULL)
