@@ -19,7 +19,8 @@ byComplexity <- function(x, model)
              x[order(x$n.trees, x$interaction.depth, x$shrinkage),] 
            },
            rf =, rfNWS =, rfLSF =, gpls =, pls =, PLS =, pam =, cforest =,
-           nb =, rpart =, ctree2 =, logitBoost=, J48 =, LMT =, ppr =, mda =, pda =, pda2 =   
+           nb =, rpart =, ctree2 =, logitBoost=, J48 =, LMT =, ppr =, mda =, pda =, pda2 =,
+           lars =, lars2 =
            {
              x[order(x[,1]),]
            },
@@ -60,7 +61,7 @@ byComplexity <- function(x, model)
              x[order(x$degree, x$nprune),]
            },
            treebag =, lda =, lm =, sddaLDA =, sddaQDA =,
-           lmStepAIC =, slda =, glm =, qda =
+           lmStepAIC =, slda =, glm =, qda =, OneR =
            {
              x
            },
@@ -99,6 +100,10 @@ byComplexity <- function(x, model)
            {
              x[order(x$NumVars, x$lambda),]
            },
+           relaxo =
+           {
+             x[order(x$phi, -x$lambda),]
+           },           
            penalized =
            {
              x[order(x$lambda1, x$lambda2),]
@@ -107,6 +112,7 @@ byComplexity <- function(x, model)
            {
              x[order(-x$eta, x$K),]
            },
+           PART = x[order(x$pruned, -x$threshold),],
            sda = x[order(x$diagonal),],
            glmnet = x[order(-x$lambda, x$alpha),]
            )
